Kwanzaa is celebrated at Beauchamp Library | syracuse.com
Description: Today on the first day of Kwanzaa, a week-long celebration which honors African heritage in African-American culture, children at the Beauchamp Branch Library read Kwanzaa stories

comments

# Kwanzaa is celebrated at Beauchamp Library

Loading Photo Gallery

Print
David Lassman | dlassman@syracuse.com By David Lassman | dlassman@syracuse.com The Post-Standard
on December 26, 2014 at 3:52 PM
View/Post Comments

Today on the first day of Kwanzaa, a week-long celebration which honors African heritage in African-American culture, children at the Beauchamp Branch Library read Kwanzaa stories and make related crafts in a celebration organized by Children's Librarian Anne Gregory. In addition a related exhibit, Kwanzaa and the African Diaspora by Vanessa Johnson is on display at the library.

View/Post Comments

## Related Stories

# House of the Week

## Valley views near Hamilton

The house, which sits on 20 acres, overlooks Lake Moraine and hillsides dotted with silos and working farms

More House of the Week homes »

# More CNY Living

- Things to do: Search local events
- Food & Drink: Recipes, reviews & more
- Weddings: Dresses, announcements & more

## Most Read

## Active Discussions

## Best of syracuse.com

Disney magic fills Oncenter War Memorial
New York State of the State address postponed
Study: NY ranks No. 2 in residents moving away